@@ -88,9 +88,9 @@ class ConfigData:
                     for sk,sv in v["subControls"].items():
                         _LOGGER.debug("  Adding Light: {0} {1}".format(sk, sv["name"]))
                         if sv["type"] == 'Switch':
-                            self.devices[sk] = LoxSwitch(sk, sv["name"], sv["type"], roomName, catName, sv["details"])
+                            self.devices[sk] = LoxSwitch(sk, sv["name"], sv["type"], roomName, catName)
                         elif sv["type"] == 'Dimmer':
-                            self.devices[sk] = LoxDimmer(sk, sv["name"], sv["type"], roomName, catName, sv["details"])
+                            self.devices[sk] = LoxDimmer(sk, sv["name"], sv["type"], roomName, catName)
                         elif sv["type"] == 'ColorPickerV2':
                             self.devices[sk] = LoxColorPickerV2(sk, sv["name"], sv["type"], roomName, catName, sv["details"])
 
