@@ -6,6 +6,7 @@ class LoxColorPickerV2:
     """Class for node abstraction."""
 
     def __init__(self, id, name, device_type, room, cat, details):
+        _LOGGER.debug("{0} init".format(id))
         self._id = id
         self._name = name
         self._device_type = device_type
@@ -32,6 +33,7 @@ class LoxColorPickerV2:
 
     @property
     def room(self):
+        _LOGGER.debug("{0} room={1}".format(self._id, self._room))
         return self._room
 
     @property
@@ -44,6 +46,7 @@ class LoxColorPickerV2:
 
     @property
     def manufacturer_name(self):
+        _LOGGER.debug("{0} manufacturer_name={1}".format(self._id, 'Loxone'))
         return 'Loxone'    
 
     @property
