@@ -5,7 +5,8 @@ _LOGGER = logging.getLogger(__name__)
 class LoxDimmer:
     """Class for node abstraction."""
 
-    def __init__(self, id, name, device_type, room, cat, details):
+    def __init__(self, id, name, device_type, room, cat, details={}):
+        _LOGGER.debug("{0} init".format(id))
         self._id = id
         self._name = name
         self._device_type = device_type
@@ -48,6 +49,7 @@ class LoxDimmer:
 
     @property
     def room(self):
+        _LOGGER.debug("{0} room={1}".format(self._id, self._room))
         return self._room
 
     @property
@@ -60,6 +62,7 @@ class LoxDimmer:
 
     @property
     def manufacturer_name(self):
+        _LOGGER.debug("{0} manufacturer_name={1}".format(self._id, 'Loxone'))
         return 'Loxone'    
 
     @property
