@@ -5,7 +5,7 @@ _LOGGER = logging.getLogger(__name__)
 class LoxSwitch:
     """Class for node abstraction."""
 
-    def __init__(self, id, name, device_type, room, cat, details):
+    def __init__(self, id, name, device_type, room, cat, details={}):
         self._id = id
         self._name = name
         self._device_type = device_type
