@@ -44,7 +44,7 @@ class Miniserver:
 
     def connect(self, loop, connection_status):
         """Connect to the miniserver."""
-        _LOGGER.debug("connect")
+        _LOGGER.debug("connect v0.0.33")
         from .wsclient import WSClient
         self.loop = loop
         self.async_connection_status_callback = connection_status
